data

package
v1.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2021 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

const EffxAPIHost = "EFFX_API_HOST"

EffxAPIHost Is the environment variable to override the API host

const EffxYamlPattern = "(.+\\.)?effx\\.ya?ml$"

EffxYamlPattern is the regex pattern for yaml files

Variables

This section is empty.

Functions

func GenerateUrl added in v1.2.0

func GenerateUrl() *url.URL

func GetIntegrationName added in v1.3.0

func GetIntegrationName() string

GetIntegrationName uses the environment to generate an effx integration name

Types

type EffxEvent added in v1.1.0

type EffxEvent struct {
	Payload *effx_api.CreateEventPayload
}

func (EffxEvent) SendEvent added in v1.1.0

func (y EffxEvent) SendEvent(apiKey string) error

Sync Updates the Effx API with yaml file contents

type EffxYaml added in v1.0.2

type EffxYaml struct {
	FilePath string
}

EffxYaml provides a data structure and methods for interacting with effx yamls

func (EffxYaml) Lint added in v1.0.2

func (y EffxYaml) Lint() error

Lint Checks for syntax errors in the yaml file

func (EffxYaml) Sync added in v1.0.2

func (y EffxYaml) Sync(apiKey string) error

Sync Updates the Effx API with yaml file contents

Jump to