Documentation
¶
Index ¶
Constants ¶
const EffxAPIHost = "EFFX_API_HOST"
EffxAPIHost Is the environment variable to override the API host
const EffxYamlPattern = "(.+\\.)?effx\\.ya?ml$"
EffxYamlPattern is the regex pattern for yaml files
Variables ¶
This section is empty.
Functions ¶
func GenerateUrl ¶ added in v1.2.0
func GetIntegrationName ¶ added in v1.3.0
func GetIntegrationName() string
GetIntegrationName uses the environment to generate an effx integration name
Types ¶
type EffxEvent ¶ added in v1.1.0
type EffxEvent struct {
Payload *effx_api.CreateEventPayload
}
Click to show internal directories.
Click to hide internal directories.